@@ -27,6 +27,7 @@ pub(crate) mod non_critical_lints {
     pub mod no_loop_func;
     pub mod no_new;
     pub mod no_new_symbol;
+    pub mod no_obj_calls;
     pub mod no_param_reassign;
     pub mod no_restricted_syntax;
     pub mod no_use_before_define;
@@ -152,6 +153,12 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
             top_level_ctxt,
             &lint_config.symbol_description,
         ));
+
+        rules.extend(no_obj_calls::no_obj_calls(
+            program,
+            top_level_ctxt,
+            &lint_config.no_obj_calls,
+        ));
     }
 
     rules
